@@ -3,12 +3,20 @@ import argparse
 import sys
 from r_freeze.r_freeze import get_packages, write_package_file
 
+
 def main():
     """Console script for r_freeze."""
     parser = argparse.ArgumentParser()
-    parser.add_argument('dir', type=str, help="Directory to look for")
-    parser.add_argument('-o', type=str, help="Name of outfile if you want to craete one")
-    parser.add_argument('--overwrite', action='store_true' ,default=False, help="Over write output file if it already exists")
+    parser.add_argument("dir", type=str, help="Directory to look for")
+    parser.add_argument(
+        "-o", type=str, help="Name of outfile if you want to craete one"
+    )
+    parser.add_argument(
+        "--overwrite",
+        action="store_true",
+        default=False,
+        help="Over write output file if it already exists",
+    )
 
     args = parser.parse_args()
     if not isinstance(args.dir, str):
