@@ -7,3 +7,5 @@ import pytest
 
 from r_freeze import r_freeze
 
+def test_ok():
+    print("ok")
